//		Copyright (c) 1999 by
//		Advanced Visual Systems Inc.
//		All Rights Reserved
//	
//	This software comprises unpublished confidential information of
//	Advanced Visual Systems Inc. and may not be used, copied or made
//	available to anyone, except in accordance with the license
//	under which it is furnished.
//	
//      This file is under Perforce control
//      $Id: //depot/express/dbproj/dbil/sdi_error.hxx#1 $
//

// file: sdi_error.hxx
// author: Patrick Li, Advanced Visual Systems
// purpose: Class definition for SDI Error handler
//
//  This class can be subclassed to add the ability to store and retrieve error
//    state. It provides a common interface for users of the SDI classes to get
//    error information.
//
#ifndef SDI_ERROR_DEFINED
#define SDI_ERROR_DEFINED 1

#define SDI_MAX_ERROR_LENGTH 1024

// Define SDI_Error_Tool class
//
class SDI_Error_Tool {
public:
   SDI_Error_Tool();
   virtual ~SDI_Error_Tool();

   // Clear errors
   //
   void ResetErrors();

   // Set errors based on various input args
   //
   void SetErrors( SDI_Error_Tool &err );
   void SetErrors( const char *sdi, const char *se = NULL, const char *db = NULL );
	void SetDBErrors( const int errcode, const char *db = NULL );
	void SetSDIErrors( const int errcode, const char *sdi = NULL );

   // Return an error string with all errors
   //
   const char *GetErrorString();

   // Return individual errors strings
   //
   const int GetSDIErrorCode() const{ return sdi_errcode; }
   const char *GetSDIError() const{ return sdi_err; }
   const char *GetSEError() const{ return se_err; }
   const char *GetDBError() const{ return db_err; }

	// Return db specific error code
	//
   const int GetDBErrorCode() const{ return db_errcode; }

protected:
   char *sdi_err;
   char *se_err;
   char *db_err;
	int	db_errcode;
	int	sdi_errcode;
   char *errString;

private:
   // Create private copy constructor and assignment operator 
   // to invalidate copys and assignments
   //
   SDI_Error_Tool( const SDI_Error_Tool & ) {}
   SDI_Error_Tool &operator=(const SDI_Error_Tool &) { return *this; }
};
#endif
